Input arguments
===============

Input file paths
----------------

.. csv-table::
   :file: tables/inputs.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1

Output file paths
-----------------

.. csv-table::
   :file: tables/outputs.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1

Preprocessing options
---------------------

.. csv-table::
   :file: tables/preprocessing.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1

Epoching options
----------------

.. csv-table::
   :file: tables/epoching.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1

Averaging options
-----------------

.. csv-table::
   :file: tables/averaging.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1

Time-frequency analsis options
------------------------------

.. csv-table::
   :file: tables/tfr.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1

Permutation test options
------------------------

.. csv-table::
   :file: tables/perm.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1

Performance options
-------------------

.. csv-table::
   :file: tables/performance.csv
   :widths: 10, 30, 30, 30
   :header-rows: 1
